==> tdepim-trinity_14.0.13.orig.tar.xz: tdepim-trinity-14.0.13/kode/kwsdl/tests/google/transport.cpp <==
/*
    This file is part of KDE.

    Copyright (c) 2005 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    
    As a special exception, permission is given to link this program
    with any edition of TQt, and distribute the resulting executable,
    without including the source code for TQt in the source distribution.
*/

#include "transport.h"

#include <kdebug.h>

Transport::Transport( const TQString &url )
{
  mUrl = url;
}

void Transport::query( const TQString &xml )
{
  mData.truncate( 0 );
  
  TQByteArray postData;
  TQDataStream stream( postData, IO_WriteOnly );
  stream.writeRawBytes( xml.utf8(), xml.utf8().length() );
  
  TDEIO::TransferJob* job = TDEIO::http_post( KURL( mUrl ), postData, false );
  if ( !job ) {
    kdWarning() << "Unable to create TDEIO job for " << mUrl << endl;
    return;
  }
  
  job->addMetaData( "UserAgent", "KWSDL" );
  job->addMetaData( "content-type", "Content-Type: text/xml; charset=utf-8" );
  
  connect( job, TQT_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ), this, TQT_SLOT( slotData( TDEIO::Job*, const TQByteArray& ) ) );
  connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ), this, TQT_SLOT( slotResult( TDEIO::Job* ) ) );
}

void Transport::slotData( TDEIO::Job*, const TQByteArray &data )
{
  unsigned int oldSize = mData.size();
  mData.resize( oldSize + data.size() );
  memcpy( mData.data() + oldSize, data.data(), data.size() );
}

void Transport::slotResult( TDEIO::Job* job )
{
  if ( job->error() != 0 ) {
    kdWarning() << "Error occurred " << job->errorText() << endl;
    kdWarning() << mData << endl;
    return;
  }
  
  emit result( TQString::fromUtf8( mData.data(), mData.size() ) );
}


#include "transport.moc"

==> tdepim-trinity_14.1.5.orig.tar.xz: tdepim-trinity-14.1.5/kode/kwsdl/tests/google/transport.cpp <==
/*
    This file is part of KDE.

    Copyright (c) 2005 Tobias Koenig <tokoe@kde.org>

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.
    
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
    GNU General Public License for more details.
    
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
    
    As a special exception, permission is given to link this program
    with any edition of TQt, and distribute the resulting executable,
    without including the source code for TQt in the source distribution.
*/

#include "transport.h"

#include <kdebug.h>

Transport::Transport( const TQString &url )
{
  mUrl = url;
}

void Transport::query( const TQString &xml )
{
  mData.truncate( 0 );
  
  TQByteArray postData;
  TQDataStream stream( postData, IO_WriteOnly );
  stream.writeRawBytes( xml.utf8(), xml.utf8().length() );
  
  TDEIO::TransferJob* job = TDEIO::http_post( KURL( mUrl ), postData, false );
  if ( !job ) {
    kdWarning() << "Unable to create TDEIO job for " << mUrl << endl;
    return;
  }
  
  job->addMetaData( "UserAgent", "KWSDL" );
  job->addMetaData( "content-type", "Content-Type: text/xml; charset=utf-8" );
  
  connect( job, TQ_SIGNAL( data( TDEIO::Job*, const TQByteArray& ) ), this, TQ_SLOT( slotData( TDEIO::Job*, const TQByteArray& ) ) );
  connect( job, TQ_SIGNAL( result( TDEIO::Job* ) ), this, TQ_SLOT( slotResult( TDEIO::Job* ) ) );
}

void Transport::slotData( TDEIO::Job*, const TQByteArray &data )
{
  unsigned int oldSize = mData.size();
  mData.resize( oldSize + data.size() );
  memcpy( mData.data() + oldSize, data.data(), data.size() );
}

void Transport::slotResult( TDEIO::Job* job )
{
  if ( job->error() != 0 ) {
    kdWarning() << "Error occurred " << job->errorText() << endl;
    kdWarning() << mData << endl;
    return;
  }
  
  emit result( TQString::fromUtf8( mData.data(), mData.size() ) );
}


#include "transport.moc"
